/*
 * sys/system.h
 *
 * Copyright 2004, Minoru Murashima. All rights reserved.
 * Distributed under the terms of the BSD License.
 */


#ifndef sys_system_h
#define sys_system_h


#include <sys/cdefs.h>


#ifndef ASM_FILE


/* exec()Ϳ륷ƥ */
typedef struct{
	unsigned int lastAddr;
}SYS_INFO;


#ifndef KERNEL

enum{
	/* åȥޥ¸ */
	USER_ESP_BEG=0xfec00000,
	PAGE_SIZE=0x1000,
};

extern SYS_INFO *sys_info;

#endif


#endif


#endif
